pub enum ComponentIndex {
Client,
Proxy(usize),
Agent,
}Expand description
Identifies a component in the conductor’s chain for tracing purposes.
Used to track message sources and destinations through the proxy chain.
Variants
Client
The client (editor) at the start of the chain.
Proxy(usize)
A proxy component at the given index.
Agent
The successor (agent in agent mode, outer conductor in proxy mode).
Implementations
Sourceimpl ComponentIndex
impl ComponentIndex
Sourcepub fn predecessor_of(proxy_index: usize) -> Self
pub fn predecessor_of(proxy_index: usize) -> Self
Return the index for the predecessor of proxy_index, which might be Client.
Sourcepub fn successor_of(proxy_index: usize, num_proxies: usize) -> Self
pub fn successor_of(proxy_index: usize, num_proxies: usize) -> Self
Return the index for the predecessor of proxy_index, which might be Client.