ConductorImpl

Struct ConductorImpl 

pub struct ConductorImpl<Host: ConductorHostRole> { /* private fields */ }
The conductor manages the proxy chain lifecycle and message routing.

It maintains connections to all components in the chain and routes messages bidirectionally between the editor, components, and agent.

Implementations

Source

impl<Host: ConductorHostRole> ConductorImpl<Host>

pub fn new( host: Host, name: impl ToString, instantiator: Host::Instantiator, mcp_bridge_mode: McpBridgeMode, ) -> Self

Source

impl ConductorImpl<Agent>

pub fn new_agent( name: impl ToString, instantiator: impl InstantiateProxiesAndAgent + 'static, mcp_bridge_mode: McpBridgeMode, ) -> Self

Create a conductor in agent mode (the last component is an agent).

Source

impl ConductorImpl<Proxy>

pub fn new_proxy( name: impl ToString, instantiator: impl InstantiateProxies + 'static, mcp_bridge_mode: McpBridgeMode, ) -> Self

Create a conductor in proxy mode (forwards to another conductor).

Source

impl<Host: ConductorHostRole> ConductorImpl<Host>

pub fn trace_to(self, dest: impl WriteEvent) -> Self

Enable trace logging to a custom destination.

Use sacp-trace-viewer to view the trace as an interactive sequence diagram.

pub fn trace_to_path(self, path: impl AsRef<Path>) -> Result<Self>

Enable trace logging to a file path.

Events will be written as newline-delimited JSON (.jsons format). Use sacp-trace-viewer to view the trace as an interactive sequence diagram.

pub fn with_trace_writer(self, writer: TraceWriter) -> Self

Enable trace logging with an existing TraceWriter.

pub async fn run(self, transport: impl ConnectTo<Host>) -> Result<(), Error>

Run the conductor with a transport.