pub struct ConductorImpl<Host: ConductorHostRole> { /* private fields */ }Expand description
The conductor manages the proxy chain lifecycle and message routing.
It maintains connections to all components in the chain and routes messages bidirectionally between the editor, components, and agent.
Implementations
Sourceimpl<Host: ConductorHostRole> ConductorImpl<Host>
impl<Host: ConductorHostRole> ConductorImpl<Host>
pub fn new( host: Host, name: impl ToString, instantiator: Host::Instantiator, mcp_bridge_mode: McpBridgeMode, ) -> Self
Sourceimpl ConductorImpl<Agent>
impl ConductorImpl<Agent>
Sourcepub fn new_agent(
name: impl ToString,
instantiator: impl InstantiateProxiesAndAgent + 'static,
mcp_bridge_mode: McpBridgeMode,
) -> Self
pub fn new_agent( name: impl ToString, instantiator: impl InstantiateProxiesAndAgent + 'static, mcp_bridge_mode: McpBridgeMode, ) -> Self
Create a conductor in agent mode (the last component is an agent).
Sourceimpl ConductorImpl<Proxy>
impl ConductorImpl<Proxy>
Sourcepub fn new_proxy(
name: impl ToString,
instantiator: impl InstantiateProxies + 'static,
mcp_bridge_mode: McpBridgeMode,
) -> Self
pub fn new_proxy( name: impl ToString, instantiator: impl InstantiateProxies + 'static, mcp_bridge_mode: McpBridgeMode, ) -> Self
Create a conductor in proxy mode (forwards to another conductor).
Sourceimpl<Host: ConductorHostRole> ConductorImpl<Host>
impl<Host: ConductorHostRole> ConductorImpl<Host>
Sourcepub fn trace_to(self, dest: impl WriteEvent) -> Self
pub fn trace_to(self, dest: impl WriteEvent) -> Self
Enable trace logging to a custom destination.
Use sacp-trace-viewer to view the trace as an interactive sequence diagram.
Sourcepub fn trace_to_path(self, path: impl AsRef<Path>) -> Result<Self>
pub fn trace_to_path(self, path: impl AsRef<Path>) -> Result<Self>
Enable trace logging to a file path.
Events will be written as newline-delimited JSON (.jsons format).
Use sacp-trace-viewer to view the trace as an interactive sequence diagram.
Sourcepub fn with_trace_writer(self, writer: TraceWriter) -> Self
pub fn with_trace_writer(self, writer: TraceWriter) -> Self
Enable trace logging with an existing TraceWriter.